@@ -20,9 +20,7 @@
    Author: Bastien Nocera <hadess@hadess.net>
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif /* HAVE_CONFIG_H */
 
 #include <string.h>
 #include <glib.h>
